@@ -13,6 +13,7 @@ OC.L10N.register(
     "Name" : "Nimi",
     "Company" : "Yritys",
     "Title" : "Nimeke",
+    "This contact is not yet synced. Edit it to save it to the server." : "Tätä yhteystietoa ei ole vielä synkronoitu. Muokkaa yhteystietoa tallentaaksesi sen palvelimelle.",
     "This contact is in read-only mode. You do not have permission to edit this contact." : "Tämä yhteystieto on \"vain luku\"-tilassa. Sinulla ei ole oikeuksia muokata tätä yhteystietoa.",
     "Download" : "Lataa",
     "Delete" : "Poista",
@@ -21,9 +22,12 @@ OC.L10N.register(
     "New contact" : "Uusi yhteystieto",
     "The contact doesn't exists anymore on the server." : "Yhteystietoa ei ole enää olemassa tällä palvelimella.",
     "Open your browser console for more details" : "Avaa selaimesi konsoli nähdäksesi lisätietoja",
+    "failed" : "epäonnistui",
+    "Select type" : "Valitse tyyppi",
     "Select Date" : "Valitse päivä",
     "Add contact in group" : "Lisää yhteystieto ryhmään",
     "No results" : "Ei tuloksia",
+    "Select option" : "Valitse valinta",
     "Copy link" : "Kopioi linkki",
     "Copied" : "Kopioitu",
     "Can not copy" : "Ei voida kopioida",
@@ -48,6 +52,7 @@ OC.L10N.register(
     "Display name" : "Näyttönimi",
     "Sort by {sorting}" : "Järjestysperuste {sorting}",
     "All contacts" : "Kaikki yhteystiedot",
+    "Unable to create the contact." : "Yhteystiedon luominen ei onnistunut.",
     "Contact not found" : "Yhteytietoa ei löytynyt",
     "Nickname" : "Kutsumanimi",
     "Detailed name" : "Täsmällinen nimi",
