@@ -2,39 +2,28 @@ OC.L10N.register(
     "contacts",
     {
     "Contacts" : "ข้อมูลผู้ติดต่อ",
-    "Address book name" : "สมุดชื่อที่อยู่",
-    "The selected image is too big (max 1MB)" : "รูปภาพที่เลือกมีขนาดใหญ่เกินไป (ขนาดไม่ควรเกิน 1 เมกะไบต์)",
-    "No contacts in here" : "ไม่มีรายชื่อในที่นี่",
-    "Name" : "ชื่อ",
-    "Organization" : "หน่วยงาน",
-    "Title" : "ชื่อเรื่อง",
-    "No search result for {query}" : "ไม่พบผลลัพธ์การค้นหาสำหรับ {query}",
-    "All contacts" : "รายชื่อทั้งหมด",
-    "Post office box" : "กล่องจดหมาย",
-    "Postal code" : "รหัสไปรษณีย์",
-    "City" : "เมือง",
-    "State or province" : "รัฐหรือจังหวัด",
-    "Country" : "ประเทศ",
-    "Address" : "ที่อยู่",
-    "(new group)" : "(กลุ่มใหม่)",
-    "Last name" : "นามสกุลจริง",
+    "Groups" : "กลุ่ม",
+    "New contact" : "รายชื่อผุ้ติดต่อใหม่",
     "First name" : "ชื่อจริง",
+    "Last name" : "นามสกุลจริง",
+    "All contacts" : "รายชื่อทั้งหมด",
+    "Nickname" : "ชื่อเล่น",
+    "Detailed name" : "รายละเอียดชื่อ",
     "Additional names" : "ชื่ออื่นๆ",
     "Prefix" : "คำนำหน้า",
     "Suffix" : "คำต่อท้าย",
-    "New contact" : "รายชื่อผุ้ติดต่อใหม่",
-    "Not grouped" : "ไม่ถูกจัดกลุ่ม",
-    "{addressbook} shared by {owner}" : "{addressbook} ถูกแชร์โดย {owner}",
-    "Contact could not be created." : "ไม่สามารถสร้างรายชื่อผู้ติดต่อ",
-    "Nickname" : "ชื่อเล่น",
-    "Detailed name" : "รายละเอียดชื่อ",
     "Notes" : "บันทึกย่อ",
     "Website" : "เว็บไซต์",
     "Federated Cloud ID" : "ไอดีคลาวด์ในเครือ",
     "Home" : "บ้าน",
     "Work" : "ที่ทำงาน",
     "Other" : "อื่นๆ",
-    "Groups" : "กลุ่ม",
+    "Address" : "ที่อยู่",
+    "Post office box" : "กล่องจดหมาย",
+    "City" : "เมือง",
+    "State or province" : "รัฐหรือจังหวัด",
+    "Postal code" : "รหัสไปรษณีย์",
+    "Country" : "ประเทศ",
     "Birthday" : "วันเกิด",
     "Anniversary" : "วันครบรอบ",
     "Date of death" : "วันที่สิ้นสุด",
@@ -47,7 +36,6 @@ OC.L10N.register(
     "Fax work" : "แฟกซ์ที่ทำงาน",
     "Pager" : "เพจเจอร์",
     "Voice" : "เสียงพูด",
-    "Social network" : "เครือข่ายทางสังคม",
-    "Settings" : "ตั้งค่า"
+    "Social network" : "เครือข่ายทางสังคม"
 },
 "nplurals=1; plural=0;");
