@@ -5,18 +5,31 @@ OC.L10N.register(
     "Details" : "详情",
     "A contacts app for Nextcloud" : "适用于 Nextcloud 的联系人应用",
     "The Nextcloud contacts app is a user interface for Nextcloud's CardDAV server. Easily sync contacts from various devices with your Nextcloud and edit them online.\n\n* 🚀 **Integration with other Nextcloud apps!** Currently Mail and Calendar – more to come.\n* 🎉 **Never forget a birthday!** You can sync birthdays and other recurring events with your Nextcloud Calendar.\n* 👥 **Sharing of Adressbooks!** You want to share your contacts with your friends or coworkers? No problem!\n* 🙈 **We’re not reinventing the wheel!** Based on the great and open SabreDAV library." : "“日历”是 Nextcloud CalDav 服务器的一个用户界面应用。通过使用此应用，您可以在不同的设备上同步您的活动并进行在线编辑。\n\n* 🚀 **集成了其他的 Nextcloud 应用！** 现在仅仅集成了联系人功能 - 将来将会集成更多。\n* 🌐 **支持WebCal！** 想要在您的日历上看到您最喜爱的球队的比赛时间？没问题！\n* 🙋 **参与人功能！** 邀请他人参与您的活动。\n* 🙈 **我们不是在做无用功！** 基于出色的 [davclient.js](https://github.com/evert/davclient.js), [ical.js](https://github.com/mozilla-comm/ical.js) 和 [fullcalendar](https://github.com/fullcalendar/fullcalendar) 库开发.",
+    "Name" : "名称",
+    "Company" : "公司",
+    "Title" : "头衔",
     "Download" : "下载",
     "Delete" : "删除",
     "Groups" : "群组",
     "New contact" : "新建联系人",
+    "Select type" : "选择类型",
+    "Select Date" : "选择日期",
+    "No results" : "无结果",
     "Copy link" : "复制链接",
+    "Copied" : "已复制",
+    "Can not copy" : "无法复制",
     "Rename" : "重命名",
     "Enabled" : "已开启",
     "Disabled" : "已禁用",
     "Share with users or groups" : "和用户或者组群共享",
+    "can edit" : "可编辑",
+    "Unable to change permissions." : "无法修改权限。",
+    "Importing into" : "导入到",
     "Import into" : "导入到",
     "First name" : "名",
     "Last name" : "姓",
+    "Display name" : "显示名称",
+    "Sort by {sorting}" : "以{sorting}排序",
     "All contacts" : "全部联系人",
     "Nickname" : "昵称",
     "Detailed name" : "全名",
@@ -73,6 +86,7 @@ OC.L10N.register(
     "Co-worker" : "同事",
     "Gender" : "性别",
     "Female" : "女性",
-    "Male" : "男性"
+    "Male" : "男性",
+    "An error occurred" : "发生一个错误."
 },
 "nplurals=1; plural=0;");
